/*

	BreakBuster для WriteMonkey, версия 2.1 от 3 ноября 2016.
	Автор — Михаил Баландин, http://balandin.online
	Работоспособность проверена с WriteMonkey 2.7.0.3.

	Расставляет в тексте неразрывные пробелы согласно правилам
	русской типографики и окружает HTML-тегами <nobr>...</nobr>
	составные слова, записанные через дефис. Данный плагин
	предназначен для подготовки текстов к веб-публикации.

	Установка: распакуйте архив в папку с плагинами WriteMonkey.

	Использование: нажмите Ctrl+F10, выберите из появившегося
	списка доступных плагинов "BreakBuster".

*/


// ------------------------------------------------------------------------------------------------------------------

// Слова и формы, всегда присоединяемые к предыдущему слову.
var JoinPrev = "б|ж|бы|же|л[иь]|не[еёй]|ни[хм]|—";

// Наиболее распространённые одно- и двухбуквенные слова.
var JoinNext = "[авикосуя]|а[хджй]|о[нхтбй]|э[хй]|яд|и[хзм]|у[смфй]|юг|е[ёй]|[зндт]а|[нпдтб]о|[нф]и|[нфт]у|ёж|[нтс]е";

// Наиболее типичные присоединения слова «уж» к предыдущему слову.
var JoinUzh = "да|ет|его|ак|колько|му|аким|акими|ем";

// ------------------------------------------------------------------------------------------------------------------

var TmpStr = monkey.text;
TmpStr = TmpStr.Replace("&nbsp;"," ");

// Для слова «уж» обрабатываем простые случаи присоединений.
TmpStr = TmpStr.Replace("Уж ","Уж_");
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "("+JoinUzh+") уж", "$1_уж", System.Text.RegularExpressions.RegexOptions.IgnoreCase);

// Присоединение к предыдущему слову.
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "[ _]("+JoinPrev+")([ \.\*,…;:!\?»\)])", "_$1$2", System.Text.RegularExpressions.RegexOptions.IgnoreCase);

// Присоединение к следующему слову.
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "([ _\*\(«„])("+JoinNext+") ", "$1$2_", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "([ _\*\(«„])("+JoinNext+") ", "$1$2_", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "([ _\*\(«„])("+JoinNext+"), ", "$1$2,_", System.Text.RegularExpressions.RegexOptions.IgnoreCase);

// Случай, когда предложение заканчивается коротким (1-3 буквы) словом, присоединяемым к предыдущему.
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "[ _]([а-яёa-zýéáó]{1,3})([\.…:;!»“\?\*\)])","_$1$2", System.Text.RegularExpressions.RegexOptions.IgnoreCase);

// Случай, когда абзац заканчивается сравнительно коротким (4 буквы) словом, присоединяемым к предыдущему.
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "[ _]([а-яёa-zýéáó]{4})([\.…:;!»“\?\*\)])\n","_$1$2\n", System.Text.RegularExpressions.RegexOptions.IgnoreCase);
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "[ _]([а-яёa-zýéáó]{4})([\.…:;!»“\?\*\)])$","_$1$2", System.Text.RegularExpressions.RegexOptions.IgnoreCase);

// Окружает HTML-тегами <NOBR>…</NOBR> составные слова, записанные через дефис.
TmpStr = System.Text.RegularExpressions.Regex.Replace(TmpStr, "([ _«„\(\*])([0-9а-яёa-zýéáó]+-[а-яёýéáó]+)", "$1<nobr>$2</nobr>", System.Text.RegularExpressions.RegexOptions.IgnoreCase);

monkey.text = TmpStr.Replace("_"," ");
